@@ -23,7 +23,7 @@
 #include <tango.h>
 
 using namespace boost::python;
- 
+
 void export_version();
 void export_enums();
 void export_constants();
@@ -80,10 +80,6 @@ BOOST_PYTHON_MODULE(_tango)
                                show_py_signatures);
 #endif
 
-    // specify that this module is actually a package
-    boost::python::object package = boost::python::scope();
-    package.attr("__path__") = "PyTango";
-
     PyEval_InitThreads();
 
     init_numpy();
