@@ -15,7 +15,7 @@ This is an internal PyTango module.
 
 from __future__ import print_function
 
-__all__ = ["DeviceClass", "device_class_init"]
+__all__ = ("DeviceClass", "device_class_init")
 
 __docformat__ = "restructuredtext"
 
