@@ -13,7 +13,7 @@
 This is an internal PyTango module.
 """
 
-__all__ = ["Group", "group_init"]
+__all__ = ("Group", "group_init")
 
 __docformat__ = "restructuredtext"
 
