@@ -13,7 +13,7 @@
 
 import os
 import sys
-import types
+import six
 import logging
 import weakref
 import inspect
@@ -28,7 +28,7 @@ from .server import Device, _to_classes, _add_classes
 from .server import get_worker, set_worker
 from .green import get_executor
 
-__all__ = ['Server']
+__all__ = ('Server',)
 
 _CLEAN_UP_TEMPLATE = """
 import sys
@@ -155,7 +155,7 @@ def create_tango_class(server, obj, tango_class_name=None, member_filter=None):
             if doc is None:
                 doc = ""
             cmd.__doc__ = doc
-            cmd = types.MethodType(cmd, None, DeviceDispatcher)
+            cmd = six.create_unbound_method(cmd, DeviceDispatcher)
             setattr(DeviceDispatcher, name, cmd)
             DeviceDispatcherClass.cmd_list[name] = \
                 [[in_type, doc], [out_type, ""]]
